summaryrefslogtreecommitdiffstats
path: root/system/core/Security.php
diff options
context:
space:
mode:
authorAndrey Andreev <narf@bofh.bg>2012-03-13 11:10:12 +0100
committerAndrey Andreev <narf@bofh.bg>2012-03-13 11:10:12 +0100
commit60138567c58dd924e2240973e34f0e3903a7ef2b (patch)
tree533c1dd40f69a534c0b03e8c327011427e458bd8 /system/core/Security.php
parent7203d54604a372fd8dd0b30bd8d4cdbd0af738bc (diff)
parentdbf4a5ad7b279b2833484e30f1168032cea9b7d3 (diff)
Merge upstream branch
Diffstat (limited to 'system/core/Security.php')
-rwxr-xr-xsystem/core/Security.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/system/core/Security.php b/system/core/Security.php
index 6f25fb5bb..cd8a61028 100755
--- a/system/core/Security.php
+++ b/system/core/Security.php
@@ -2,7 +2,7 @@
/**
* CodeIgniter
*
- * An open source application development framework for PHP 5.1.6 or newer
+ * An open source application development framework for PHP 5.2.4 or newer
*
* NOTICE OF LICENSE
*
@@ -138,8 +138,8 @@ class CI_Security {
*/
public function csrf_verify()
{
- // If no POST data exists we will set the CSRF cookie
- if (count($_POST) === 0)
+ // If it's not a POST request we will set the CSRF cookie
+ if (strtoupper($_SERVER['REQUEST_METHOD']) !== 'POST')
{
return $this->csrf_set_cookie();
}